auctex-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[AUCTeX-diffs] GNU AUCTeX branch, master, updated. 32bc5485bc93b720c93c9


From: Ikumi Keita
Subject: [AUCTeX-diffs] GNU AUCTeX branch, master, updated. 32bc5485bc93b720c93c96c166ece4d744f3bea5
Date: Thu, 15 Nov 2018 01:15:38 -0500 (EST)

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "GNU AUCTeX".

The branch, master has been updated
       via  32bc5485bc93b720c93c96c166ece4d744f3bea5 (commit)
       via  dad0c605e19bff657118022e9c475fc23a4ca85b (commit)
      from  f213b1b8214dc4b6fce985e5c4bd99426f7d55ae (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit 32bc5485bc93b720c93c96c166ece4d744f3bea5
Author: Ikumi Keita <address@hidden>
Date:   Sat Nov 10 23:33:39 2018 +0900

    ; Fix typos and doc string
    
    * doc/auctex.texi:
    * latex.el: preceed{ing,ed} -> preced{ing,ed}
    (LaTeX--find-preceding-left-macro-name): Rename from wrongly-spelled
    `LaTeX-find-preceeding-left-macro-name'.  Change all the caller.
    Supply `define-obsolete-function-alias' for backward compatibility.
    Fix comments and doc strings.

diff --git a/doc/auctex.texi b/doc/auctex.texi
index 9761ba7..6fd65a8 100644
--- a/doc/auctex.texi
+++ b/doc/auctex.texi
@@ -519,7 +519,7 @@ immediately adds the corresponding right brace @samp{)}, 
@address@hidden or
 @samp{]}.  The point is left after the opening brace.  If there is an
 active region, braces are put around it.
 
-They recognize the preceeding backslash or size adjusting macros such
+They recognize the preceding backslash or size adjusting macros such
 as @samp{\left}, @samp{\bigl} etc., so the following completions will
 occur:
 @itemize @bullet
diff --git a/latex.el b/latex.el
index 4c0a75b..98621ff 100644
--- a/latex.el
+++ b/latex.el
@@ -5377,9 +5377,11 @@ commands are defined:
   "Insert \\STRING{}.  If DOLLAR is non-nil, put $'s around it.
 If `TeX-electric-math' is non-nil wrap that symbols around the
 string."
-  (if dollar (insert (or (car TeX-electric-math) "$")))
-  (funcall LaTeX-math-insert-function string)
-  (if dollar (insert (or (cdr TeX-electric-math) "$"))))
+  (when dollar
+    (insert (or (car TeX-electric-math) "$"))
+    (save-excursion
+      (insert (or (cdr TeX-electric-math) "$"))))
+  (funcall LaTeX-math-insert-function string))
 
 (defun LaTeX-math-cal (char dollar)
   "Insert a {\\cal CHAR}.  If DOLLAR is non-nil, put $'s around it.

-----------------------------------------------------------------------

Summary of changes:
 doc/auctex.texi |  2 +-
 latex.el        | 29 +++++++++++++++++------------
 2 files changed, 18 insertions(+), 13 deletions(-)


hooks/post-receive
diff --git a/latex.el b/latex.el
index 98621ff..9cb97de 100644
--- a/latex.el
+++ b/latex.el
@@ -2764,9 +2764,8 @@ string."
 (defun TeX-arg-insert-right-brace-maybe (optional)
   "Insert the suitable right brace macro such as \\rangle.
 Insertion is done when `TeX-arg-right-insert-p' is non-nil.
-If the left brace macro is preceeded by \\left, \\bigl etc.,
-supply the corresponding macro such as \\right before the right brace macro.
-OPTIONAL is ignored."
+If the left brace macro is preceded by \\left, \\bigl etc.,
+supply the corresponding macro such as \\right before the right brace macro."
   ;; Nothing is done when TeX-arg-right-insert-p is nil.
   (when TeX-arg-right-insert-p
     (let (left-brace left-macro)
@@ -2776,9 +2775,9 @@ OPTIONAL is ignored."
                          (point)
                          (progn (backward-word) (backward-char)
                                 (point)))
              ;; Obtain the name of preceeding left macro, if any,
              ;; such as "left", "bigl" etc.
-             left-macro (LaTeX-find-preceeding-left-macro-name)))
+             left-macro (LaTeX--find-preceding-left-macro-name)))
       (save-excursion
        (if (TeX-active-mark)
            (goto-char (mark)))
@@ -2817,9 +2816,9 @@ Normally bound to keys \(, { and [."
                ;; Otherwise, don't search for left macros.
                (setq skip-p t)))
          (unless skip-p
            ;; Obtain the name of preceeding left macro, if any,
            ;; such as "left", "bigl" etc.
-           (setq lmacro (LaTeX-find-preceeding-left-macro-name))))
+           (setq lmacro (LaTeX--find-preceding-left-macro-name))))
         (let ((TeX-arg-right-insert-p t)
               ;; "{" and "}" are paired temporally so that typing
              ;; a single "{" should insert a pair "{}".
@@ -2867,9 +2866,9 @@ is nil, consult user which brace should be used."
                        (or rbrace "."))) TeX-left-right-braces
                        nil nil nil nil (or rbrace ".")))))))
 
-(defun LaTeX-find-preceeding-left-macro-name ()
+(defun LaTeX--find-preceding-left-macro-name ()
   "Return the left macro name just before the point, if any.
-If the preceeding macro isn't left macros such as \\left, \\bigl etc.,
+If the preceding macro isn't left macros such as \\left, \\bigl etc.,
 return nil.
 If the point is just after unescaped `TeX-esc', return the null string."
   ;; \left-!- => "left"
@@ -2891,6 +2890,10 @@ If the point is just after unescaped `TeX-esc', return 
the null string."
             (or (string= name "")
                 (assoc name LaTeX-left-right-macros-association)))
        name)))
+(define-obsolete-function-alias
+  'LaTeX-find-preceeding-left-macro-name
+  #'LaTeX--find-preceding-left-macro-name "AUCTeX 12.2"
+  "Compatibility function for typo in its name.")
 
 (defcustom LaTeX-default-author 'user-full-name
   "Initial input to `LaTeX-arg-author' prompt.
@@ -2776,9 +2775,9 @@ OPTIONAL is ignored."
                          (progn (backward-word) (backward-char)
                                 (point)))
-             ;; Obtain the name of preceeding left macro, if any,
+             ;; Obtain the name of preceding left macro, if any,
              ;; such as "left", "bigl" etc.
@@ -2817,9 +2816,9 @@ Normally bound to keys \(, { and [."
                (setq skip-p t)))
          (unless skip-p
-           ;; Obtain the name of preceeding left macro, if any,
+           ;; Obtain the name of preceding left macro, if any,
            ;; such as "left", "bigl" etc.

commit dad0c605e19bff657118022e9c475fc23a4ca85b
Author: Ikumi Keita <address@hidden>
Date:   Sat Nov 10 23:06:18 2018 +0900

    Surround both \langle and \rangle with math delimiter
    
    * latex.el (LaTeX-math-insert): Typing "C-u ` (" used to result in
    "$\langle$\rangle" when `LaTeX-math-mode' and
    `LaTeX-electric-left-right-brace' are enabled.  Fix this to insert
    "$\langle\rangle$" instead.

-- 
GNU AUCTeX



reply via email to

[Prev in Thread] Current Thread [Next in Thread]